oceanum.datamesh.Datasource
===========================

.. currentmodule:: oceanum.datamesh

.. autoclass:: Datasource

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Datasource.attributes
      ~Datasource.bounds
      ~Datasource.container
      ~Datasource.description
      ~Datasource.geometry
      ~Datasource.name
      ~Datasource.tend
      ~Datasource.tstart
      ~Datasource.variables
   
   

   
   
   .. rubric:: Methods
   
   .. automethod:: __init__
   .. automethod:: load
   
   